@@ -44,10 +44,10 @@ v32 = v3.scaled_get
 p v31
 p v32
 
-print "** scaled_get type fixed to sfloat\n"
-NetCDFVar.scaled_get_type = NArray::SFLOAT
+print "** unpack type fixed to sfloat\n"
+NetCDFVar.unpack_type = NArray::SFLOAT
 v33 = v3.scaled_get
 p v33
-NetCDFVar.scaled_get_type = NArray::INT
+NetCDFVar.unpack_type = NArray::INT
 v33 = v3.scaled_get
 p v33
